﻿define("gl-translations/component/command/SubmitForTranslation", [
    "dojox/layout/ResizeHandle",
    "dojo/on",
    "dojo/_base/connect",
    "dojo/parser",
    "dojo/_base/lang",
    "epi/routes",
    "dojo/when",
    "dojo/topic",
    "epi/string",
    "dojo/_base/declare",
    "epi/shell/widget/dialog/Alert",
    "epi/shell/DialogService",
    "epi/dependency",
    "epi/shell/command/_Command",
    "epi/shell/TypeDescriptorManager",
    "epi/shell/widget/Iframe",
    "epi/shell/widget/overlay/OverlayContainer",
    "epi/shell/widget/dialog/LightWeight",
    "epi/shell/widget/dialog/Dialog",
    "epi-cms/widget/_HasChildDialogMixin",
    "epi-cms/core/ContentReference",
    "epi/shell/ViewSettings",
    "epi/shell/socket/hub",
    "epi/shell/command/_SelectionCommandMixin",
    "epi-cms/_ContentContextMixin",
    "epi-cms/contentediting/ContentActionSupport",
    "dijit/layout/_LayoutWidget",
    "epi/shell/widget/_ActionProviderWidget"
],

    function (
        ResizeHandle, on,
        connect,
        parser,
        lang,
        routes,
        when,
        topic,
        epistring,
        declare,
        Alert,
        DialogService,
        dependency,
        _Command,
        TypeDescriptorManager,
        LegacyDialogPopup,
        Overlay,
        Light,
        Dialog,
        _HasChildDialogMixin,
        ContentReference,
        ViewSettings,
        hub,
        _SelectionCommandMixin,
        _ContentContextMixin,
        ContentActionSupport,
        _LayoutWidget,
        _ActionProviderWidget
    ) {

        return declare([_Command, _HasChildDialogMixin, _ContentContextMixin], {

            label: "Translate",

            iconClass: "epi-iconTranslate",
            translationDialogUrl: "ClientResources/Scripts/Asset/Templates/TranslationConfigurator.aspx",
            projectJobId: null,
            dataObject: null,
            constructor: function () {

                // summary:
                //        Constructs the object and sets up a reference to the content data store.
                // tags:
                //        public

            },

            setLabel: function (newLabel) {
                this.label = newLabel;
            },
            _execute: function () {

                if (this.selection) {
                    this.projectJobId = this.selection.data[0].data.contentLink;
                    this.dataObject = this.selection.data[0].data;
                }
                else {
                    this.projectJobId = this.model.contentLink;
                    this.dataObject = this.model.contentLink;
                }

                this.store = dependency.resolve("epi.storeregistry").get("globallink.translationprojectstore");
                var contentWithoutVersion = (new ContentReference(this.projectJobId)).createVersionUnspecificReference().toString();
                var contentWithWorkingId = (new ContentReference(this.projectJobId)).toString();
                var promise = this.store.get(contentWithWorkingId + "_-" + Math.floor(Math.random() * 10000));
                var self = this;
                when(promise, function (value) {
                    if (value && value.status && value.status == 400) {
                        var dialog = new Alert({
                            heading: "Cannot submit for Translation",
                            destroyOnHide: true,
                            description: epistring.toHTML(value.message)
                        });
                        dialog.show();
                    } else {
                        self._showDialog();
                    }
                }, function (error) {
                    var dialog = new Alert({
                        heading: "Cannot submit for Translation",
                        destroyOnHide: true,
                        description: epistring.toHTML(error.xhr.statusText)
                    });
                    dialog.show();
                });
            },

            _showDialog: function () {
                if (!this._dialog || this._dialog._destroyed) {
                    var params = this._getLegacyDialogParameters();
                    var cmsPath = routes.getActionPath({ id: this.projectJobId, jobId: this.projectJobId }, routes.getActionPath({
                        moduleArea: "GlobalLink.Translation",
                        controller: "Dashboard",
                        action: "TranslationConfigurator"
                    }));
                    
                    this._dialog = new LegacyDialogPopup(lang.mixin(params, {
                        url: cmsPath,
                        baseUrl: cmsPath,
                        dialogArguments: window.document,
                        onUnload: this._onDialogHide,
                        currentContext: this,

                    }));
                    
                    this._ds = new Dialog({
                        defaultActionsVisible: false,
                        content: this._dialog,
                        dialogClass: "epi-dialog-landscape epi-dialog-landscape__autosize epi-dialog--wide"
                    });
                    
                    when(this._ds.onLoadDeferred, lang.hitch(this, function () {
                        let dialogid = this._dialog.id;
                        let dialogEl = document.querySelector('#' + dialogid);
                        dialogEl.style.height = '100%';
                        //dialogEl.parentElement.style.height = '90% !important';
                        let id = dialogEl.closest('div.dijitDialog').id;
                        var li = document.querySelector('#' + id);
                        var title = document.querySelector('#' + id + ' .dijitDialogTitleBar');
                        var footer = document.querySelector('#' + id + ' .dijitDialogPaneActionBar');
                        var content = document.querySelector('#' + id + ' .epi-dialogPaneContent');
                        content.style.height = '90%';
                        var contentArea = document.querySelector('#' + id + ' .dijitDialogPaneContentArea');
                        contentArea.style.height = '100%';
                        footer.style.display = 'none';
                        //title.style.display = 'none';
                        li.style.width = '90%';
                        li.style.height = '90%';
                        li.style.left = '5%';
                        li.style.maxWidth = "100%";
                        li.style.minWidth = "85%";
                    }));
                    
                    //this._overlay = 
                    this._dialog.on("Load", lang.hitch(this, function () {
                        var iframeWindow = this._dialog;
                        var elem = document.querySelector('#' + iframeWindow.id);
                        
                        iframeWindow.on("submitTranslation", lang.hitch(this, function () {
                            this._ds.hide();
                        }));
                        

                        //Show pop-up confirmation message right after Translation Job Wizard is closed
                        iframeWindow.on("showConfirmDialogForTranslationJob", lang.hitch(this, function (data) {
                            var cmsPath = routes.getActionPath({
                                moduleArea: "CMS",
                                controller: "Home",
                                action: "Index"
                            });
                            var dashboardUrl = routes.getActionPath({
                                path: "Dashboard",
                                moduleArea: "globallink.translation"
                            }, "/" + cmsPath.split("/")[1] + "/{moduleArea}/{path}")
                            DialogService.confirmation({
                                confirmActionText: "View Dashboard",
                                cancelActionText: "Close",
                                heading: 'GlobalLink Translation Jobs',
                                destroyOnHide: true,
                                defaultActionsVisible: false,
                                description: data.detail
                            }).then(function () {
                                window.open(dashboardUrl, '_blank').focus();
                            }).otherwise(function () {
                                
                            });
                            
                        }));
                        iframeWindow.on("showConfirmMessageForTranslationJob", lang.hitch(this, function (data) {
                            var dialogConfirm = new Alert({
                                heading: 'GlobalLink Translation Jobs',
                                destroyOnHide: true,
                                description: data.detail
                            });
                            dialogConfirm.show();
                        }));
                    }));

                    this._ds.show();
                };
                
            },

            destroy: function () {
                if (this._dialog) {
                    this._dialog.destroyRecursive();
                    delete this._dialog;
                }
                this.inherited(arguments);
            },

            _onDialogHide: function (dataObject) {
                if (this._dialog) {
                    this._dialog.hide();
                }

            },

            _getLegacyDialogParameters: function () {
                var width = window.outerWidth * 88 / 100;
                var height = window.outerHeight * 70 / 100;
                return {
                    autoFit: true,
                    features: {
                        width: width,
                        height: height
                    }
                };
            },

            _getLegacyDialogUrl: function (cmsPath) {

                var params = {};
                if (this.projectJobId) {
                    params.jobId = dojo.toJson(this.projectJobId);
                }

                return routes.getActionPath(params, this.translationDialogUrl);
            },

            _onModelChange: function () {

                var model = this.model.contentData;
                var createAction = ContentActionSupport.action.Create;
                var canCreate = ContentActionSupport.hasAccessToAction(model, createAction, null, true);

                var editAction = ContentActionSupport.action.Edit;
                var canEdit = ContentActionSupport.hasAccessToAction(model, editAction, null, true);

//                var adminAction = ContentActionSupport.action.Administer;
//                var canAdmin = ContentActionSupport.hasAccessToAction(model, adminAction, null, true);

//                var canExecute = canCreate && canEdit && canAdmin;
                var canExecute = canCreate && canEdit;
                this._updateAvailable();
                this.set("canExecute", canExecute);
            },

            _updateAvailable: function () {

                var validTypeIdentifier = "globallink.translation.core.translationproject";
                var isAvailable = TypeDescriptorManager.isBaseTypeIdentifier(this.model ? (this.model.contentData ? this.model.contentData.typeIdentifier : "") : "", validTypeIdentifier);
                var containedTypes = this.model.containedTypes;
                if (this.model && containedTypes && containedTypes.includes(validTypeIdentifier)) {
                    isAvailable = true;
                }

                this.set("isAvailable", !!isAvailable);
            }
        });
    });
