﻿define("gl-translations/component/LocaleBlockContainer", [
    "dojo/_base/declare",
    "dojo/_base/lang",

    "epi/shell/layout/SimpleContainer"
],
    function (
        declare,
        lang,

        SimpleContainer
    ) {

        return declare([SimpleContainer], {
            ticketJson: null,
            ticketDropdown: null,
            sourceDropdown: null,
            targetsDropdown: null,
            customAttributes: null,

            addChild: function (child) {

                this.inherited(arguments);

                if (child.name.indexOf("locale.projectTicket") >= 0) {
                    this.ticketDropdown = child;
                    this.own(this.ticketDropdown.on("change", lang.hitch(this, this._updateSourceDropdown)));
                    this.own(this.ticketDropdown.on("change", lang.hitch(this, this._updateTargetsDropdown)));
                    this.own(this.ticketDropdown.on("change", lang.hitch(this, this._updateAttributesDropdown)));
                } else if (child.name.indexOf("locale.sourceLocale") >= 0) {
                    this.sourceDropdown = child;
                    this.own(this.sourceDropdown.on("change", lang.hitch(this, this._updateTargetsDropdown)));
                    this._updateSourceDropdown();
                } else if (child.name.indexOf("locale.targetLocales") >= 0) {
                    this.targetsDropdown = child;
                    this._updateTargetsDropdown();
                }
                else if (child.name.indexOf("locale.customAttributes") >= 0) {
                    this.customAttributes = child;
                    this._updateAttributesDropdown();
                }
                else if (child.name.indexOf("locale.ticketJson") >= 0) {
                    this.ticketJson = child;
                }
            },

            _updateSourceDropdown: function () {
                var ticketValue = this.ticketDropdown.value;
                if (!ticketValue) {
                    return;
                }
                var selectedTicket = JSON.parse(ticketValue);
                
                var avaiableSources = selectedTicket.LanguageDirections.map(function(obj){
                    return obj.SourceLanguage;
                });

                avaiableSources = avaiableSources.filter(function (item, pos) {
                    return avaiableSources.indexOf(item) == pos;
                });

                var selectedSourceMix = this.sourceDropdown.value;
                if (selectedSourceMix != null && selectedSourceMix.length > 0) {
                    var selectedSource = selectedSourceMix.split(':')[0];
                    var selectedGL = selectedSourceMix.split(':')[1];
                    if (avaiableSources.indexOf(selectedGL) == -1) {

                        this.sourceDropdown.set("value", null);

                    }
                }
                

                var self = this;
                this.sourceDropdown.set("filter", function (source) {
                    var currentSource = undefined;
					for(var i=0; i<self.sourceDropdown.selections.length;i++){
	   				    var obj = self.sourceDropdown.selections[i];
                        if (obj.value === source.value)
                            currentSource = obj
                    }
                    var gl = currentSource.value.split(':')[1];
                    return avaiableSources.indexOf(gl) != -1;
                });
            },

            _updateTargetsDropdown: function () {
                var ticketValue = this.ticketDropdown.value;
                if (!ticketValue) {
                    return;
                }
                var sourceValue = this.sourceDropdown.value;
                var selectedTicket = JSON.parse(ticketValue);

                var selectedSourceMix = sourceValue;
                

                var languageDirectionsFiltedBySource;
                if (selectedSourceMix != null) {
                    var selectedGL = selectedSourceMix.split(':')[1];
                    languageDirectionsFiltedBySource = selectedTicket.LanguageDirections.filter(function (ld) { return ld.SourceLanguage == selectedGL});
                }
                else {
                    languageDirectionsFiltedBySource = selectedTicket.LanguageDirections;
                }

                var avaiableTargets = languageDirectionsFiltedBySource.map(function(obj) {
                    return obj.TargetLanguage;
                });

                avaiableTargets = avaiableTargets.filter(function (item, pos) {
                    return avaiableTargets.indexOf(item) == pos;
                });

                var selectedTarget = this.targetsDropdown.value;
                if (selectedTarget != null && selectedTarget.length > 0) {
                    var numberOfSelectedTargets = 0;
                    var arSelectedTarget = selectedTarget.split(',');
                    for (var i = 0; i < this.targetsDropdown.selections.length; i++) {
                        var selectionTarget = this.targetsDropdown.selections[i];
                        var selectionVal = selectionTarget.value.split(':')[0];
                        var gl = selectionTarget.value.split(':')[1];
                        if (arSelectedTarget.indexOf(selectionTarget.value) > -1 && avaiableTargets.indexOf(gl) > -1) {
                            numberOfSelectedTargets++;
                        }
                    }

                    if (numberOfSelectedTargets == 0) {
                        this.targetsDropdown.set("value", null);
                    }
                }

                var self = this;
                this.targetsDropdown.set("filter", function (target) {
                    var gl = target.value.split(':')[1];
                    return avaiableTargets.indexOf(gl) != -1;
                });
            },

            _updateAttributesDropdown: function () {
                var ticketValue = this.ticketDropdown.value;
                if (!ticketValue) {
                    return;
                }
                var selectedTicket = JSON.parse(ticketValue);
                var ticket = selectedTicket.Ticket;

                var ca = selectedTicket.CustomAttributes;
                var avaiableTargets = [];
                if (ca && ca.length > 0) {
                    avaiableTargets = ca.map(function (obj) {
                        return obj.name;
                    });
                }

                var self = this;
                this.customAttributes.set("filter", function (target) {
                    return avaiableTargets.indexOf(target.text) != -1 && target.value.indexOf(ticket) >=0;
                });
            }
        });
    });